# Distributions [![Build Status](https://travis-ci.org/forcedotcom/distributions.svg?branch=master)](https://travis-ci.org/forcedotcom/distributions)

Distributions provides low-level primitives for Bayesian MCMC
inference in Python and C++ including:

* special numerical functions,
* samplers and density functions from a variety of distributions,
* conjugate component models (e.g., gamma-Poisson, normal-inverse-chi-squared),
* clustering models (e.g., CRP, Pitman-Yor), and
* efficient wrappers for mixture models.

Distributions powered a machine-learning-as-a-service for Prior Knowledge Inc.,
and now powers machine learning infrastructure at Salesforce.com.


## Installation

distributions with pip:

    pip install distributions

For help with other builds, see
[the installation documentation](http://distributions.readthedocs.org/en/latest/installation.html).


## Documentation

The official documentation lives at http://distributions.readthedocs.org/.

Branch-specific documentation lives at

* [Overview](/doc/overview.rst)
* [Installation](/doc/installation.rst)


## Authors (alphabetically)

* Jonathan Glidden <https://twitter.com/jhglidden>
* Eric Jonas <https://twitter.com/stochastician>
* Fritz Obermeyer <https://github.com/fritzo>
* Cap Petschulat <https://github.com/cap>


## License

Copyright (c) 2014 Salesforce.com, Inc. All rights reserved.

Licensed under the Revised BSD License. See [LICENSE.txt](LICENSE.txt)
for details.
